@@ -215,8 +215,8 @@ def collate_metadata(metadata_dict):
             generate_collated_metadata(metadata_dict), key=count_input_paths
         )
     )
-    meta_se = tuple(g for k, g in meta if k == 1)
-    meta_pe = tuple(g for k, g in meta if k == 2)
+    meta_se = tuple(g for k, g in meta if k == 1)[0]
+    meta_pe = tuple(g for k, g in meta if k == 2)[0]
     return meta_se, meta_pe
 
 
@@ -337,7 +337,7 @@ def get_genotypes(
                     metadata_quasar_input_paths_se = pool.starmap(
                         partial(
                             prepare_quasar_input_from_metadata,
-                            **prepare_quasar_input_params(temp_dir_name, len(meta_se), pe=False)
+                            **prepare_quasar_input_params(temp_dir_name, len(meta_se[0]), pe=False)
                         ),
                         meta_se[0]
                     )
@@ -347,7 +347,7 @@ def get_genotypes(
                     metadata_quasar_input_paths_pe = pool.starmap(
                         partial(
                             prepare_quasar_input_from_metadata,
-                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe), pe=True)
+                            **prepare_quasar_input_params(temp_dir_name, len(meta_pe[0]), pe=True)
                         ),
                         meta_pe[0]
                     )
@@ -558,7 +558,8 @@ def main():
         vcf = tuple(vcf)
     if args.vcf_chr:
         pyQuASAR.write_split_vcf(vcf, args.vcf_chr)
-    os.remove(temp_file_name)
+    if args.query_snps:
+        os.remove(temp_file_name)
     if not args.quiet:
         for line in vcf:
             print(line)
